{% extends 'base.html' %}
{% load i18n %}
{% block title %}{% trans "Create Domain" %}{% endblock %}

{% block page_header %}
  {% include "horizon/common/_page_header.html" with title=_("Create Domain") %}
{% endblock page_header %}

{% block main %}
    {% include 'project/dns_domains/_create_domain.html' %}
{% endblock %}
